@@ -44,9 +44,7 @@ typedef struct {
         GtkWidget      *notebook;
         GtkWidget      *header_bar;
         GtkWidget      *back_button;
-        GtkImage       *back_button_image;
         GtkWidget      *forward_button;
-        GtkImage       *forward_button_image;
         GtkMenuButton  *gear_menu_button;
         GtkWidget      *grid_sidebar;
         GtkWidget      *grid_documents;
@@ -123,6 +121,9 @@ static void           on_search_mode_enabled_changed (GtkSearchBar    *search_ba
                                                       DhWindow        *window);
 static void           on_search_entry_activated      (GtkEntry        *entry,
                                                       DhWindow        *window);
+static gboolean      on_search_entry_key_press       (GtkEntry    *entry,
+                                                      GdkEventKey *event,
+                                                      DhWindow    *window);
 static GtkWidget *    window_new_tab_label           (DhWindow        *window,
                                                       const gchar     *label,
                                                       const GtkWidget *parent);
@@ -316,6 +317,20 @@ window_update_zoom_actions_state (DhWindow *window)
         g_simple_action_set_enabled (G_SIMPLE_ACTION (action), enabled);
 }
 
+static void
+show_sidebar_cb (GSimpleAction *action,
+                    GVariant      *parameter,
+                    gpointer       user_data)
+{
+        DhWindow *window = user_data;
+        DhWindowPrivate *priv = dh_window_get_instance_private (window);
+
+        gboolean visible = !gtk_widget_get_visible (priv->grid_sidebar);
+
+        g_simple_action_set_state (action, g_variant_new_boolean(visible));
+        gtk_widget_set_visible (priv->grid_sidebar, visible);
+}
+
 static void
 zoom_in_cb (GSimpleAction *action,
             GVariant      *parameter,
@@ -455,6 +470,7 @@ static GActionEntry win_entries[] = {
         { "find-next",        find_next_cb,        NULL, NULL, NULL },
         { "find-previous",    find_previous_cb,    NULL, NULL, NULL },
         /* view */
+        { "show-sidebar",     NULL,     NULL, "false", show_sidebar_cb },
         { "zoom-in",          zoom_in_cb,          NULL, NULL, NULL },
         { "zoom-out",         zoom_out_cb,         NULL, NULL, NULL },
         { "zoom-default",     zoom_default_cb,     NULL, NULL, NULL },
@@ -598,9 +614,7 @@ dh_window_class_init (DhWindowClass *klass)
         gtk_widget_class_bind_template_child_private (widget_class, DhWindow, gear_app_menu);
         gtk_widget_class_bind_template_child_private (widget_class, DhWindow, header_bar);
         gtk_widget_class_bind_template_child_private (widget_class, DhWindow, back_button);
-        gtk_widget_class_bind_template_child_private (widget_class, DhWindow, back_button_image);
         gtk_widget_class_bind_template_child_private (widget_class, DhWindow, forward_button);
-        gtk_widget_class_bind_template_child_private (widget_class, DhWindow, forward_button_image);
         gtk_widget_class_bind_template_child_private (widget_class, DhWindow, gear_menu_button);
         gtk_widget_class_bind_template_child_private (widget_class, DhWindow, hpaned);
         gtk_widget_class_bind_template_child_private (widget_class, DhWindow, grid_sidebar);
@@ -666,17 +680,6 @@ window_populate (DhWindow *window)
         priv = dh_window_get_instance_private (window);
         book_manager = dh_app_peek_book_manager (DH_APP (gtk_window_get_application (GTK_WINDOW (window))));
 
-        if (gtk_widget_get_direction (GTK_WIDGET (window)) == GTK_TEXT_DIR_RTL) {
-                prev_icon = "go-previous-rtl-symbolic";
-                next_icon = "go-next-rtl-symbolic";
-        } else {
-                prev_icon = "go-previous-symbolic";
-                next_icon = "go-next-symbolic";
-        }
-
-        gtk_image_set_from_icon_name (priv->back_button_image, prev_icon, GTK_ICON_SIZE_MENU);
-        gtk_image_set_from_icon_name (priv->forward_button_image, next_icon, GTK_ICON_SIZE_MENU);
-
         /* Sidebar */
         priv->sidebar = dh_sidebar_new (book_manager);
         gtk_widget_set_vexpand (priv->sidebar, TRUE);
@@ -713,6 +716,10 @@ window_populate (DhWindow *window)
                           "activate",
                           G_CALLBACK (on_search_entry_activated),
                           window);
+        g_signal_connect (priv->search_entry,
+                          "key-press-event",
+                          G_CALLBACK (on_search_entry_key_press),
+                          window);
         g_signal_connect (priv->go_up_button,
                           "clicked",
                           G_CALLBACK (window_find_previous_cb),
@@ -1038,6 +1045,19 @@ on_search_entry_activated (GtkEntry *entry,
         findbar_find_next (window);
 }
 
+static gboolean
+on_search_entry_key_press (GtkEntry    *entry,
+                           GdkEventKey *event,
+                           DhWindow    *window)
+{
+        if (event->keyval == GDK_KEY_Return && event->state & GDK_SHIFT_MASK) {
+                findbar_find_previous (window);
+                return TRUE;
+        }
+
+        return FALSE;
+}
+
 #if 0
 static void
 window_web_view_open_new_tab_cb (WebKitWebView *web_view,
@@ -1212,6 +1232,7 @@ window_new_tab_label (DhWindow        *window,
 
         label = gtk_label_new (str);
         gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
+        gtk_widget_set_halign (label, GTK_ALIGN_CENTER);
         gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
         gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 
